Validate a Data Frame for LCMD Imputation
check_dataframe_validity.RdEnsures the input is a data frame with at least 1 column, 2 rows, and that all columns are numeric.
check_dataframe_validity.RdEnsures the input is a data frame with at least 1 column, 2 rows, and that all columns are numeric.