Skip to contents

A dataframe summarizing missing values and minimum values from df1.

Usage

data(data_meta_features)

Format

A data frame with 100 rows and 3 variables:

ID_feature

Feature names from data

missing_pct

percentage of missing values for each feature

LOD

limit of detection is the minimum feature value / 2